@@ -21,6 +21,7 @@
 */
 
 #include <Lum/Images/Image.h>
+#include <Lum/Images/StatefulImage.h>
 
 #include <Lum/OS/Image.h>
 
@@ -31,18 +32,24 @@ namespace Lum {
   class LUMAPI Image : public Object
   {
   private:
-    Images::ImageRef extImage;
-    OS::ImageRef     osImage;
+    Images::ImageRef         extImage;
+    Images::StatefulImageRef extStatefulImage;
+    OS::ImageRef             osImage;
 
   public:
     Image();
     ~Image();
 
     void SetImage(Images::Image *image);
+    void SetImage(Images::StatefulImage *image);
     void SetImage(OS::Image *image);
 
     void CalcSize();
     void Draw(int x, int y, size_t w, size_t h);
+
+    static Image* Create(Images::Image *image);
+    static Image* Create(Images::StatefulImage *image);
+    static Image* Create(OS::Image *image);
   };
 }
 
