@@ -24,6 +24,8 @@
 
 #include <Lum/OS/DrawInfo.h>
 
+#include <Lum/OS/Base/Event.h>
+
 namespace Lum {
   namespace OS {
     namespace Base {
@@ -73,6 +75,12 @@ namespace Lum {
         OS::Window::Type     type;
         bool                 grabMouse;
         bool                 grabKeyboard;
+        MouseEvent           oldButton;
+        MouseEvent           lastButton;
+        MouseEvent           thisButton;
+        Lum::Base::SystemTime oldPress;
+        Lum::Base::SystemTime lastPress;
+        Lum::Base::SystemTime thisPress;
 
       public:
         Window();
@@ -162,6 +170,9 @@ namespace Lum {
         void GrabMouse(bool grab);
         void GrabKeyboard(bool grab);
 
+        bool IsDoubleClicked() const;
+        const OS::MouseEvent& GetLastButtonClickEvent() const;
+
         void AcquireKeyboardInput();
         void ReleaseKeyboardInput();
 
