@@ -37,12 +37,6 @@ namespace Lum {
       private:
         Display     *display;
 
-        MouseEvent  oldButton;
-        MouseEvent  lastButton;
-        MouseEvent  thisButton;
-        DWORD       oldPress,
-                    lastPress,
-                    thisPress;
         long        balloonId;
 
 
@@ -56,6 +50,7 @@ namespace Lum {
 
       public:
         Window(OS::Display* display);
+        ~Window();
 
         // setter
         void SetTitle(const std::wstring& name);
@@ -87,9 +82,6 @@ namespace Lum {
 
         bool SendBalloonMessage(const std::wstring& text,unsigned long timeout);
 
-        bool IsDoubleClicked() const;
-        bool IsTrippleClicked() const;
-
         LRESULT MessageHandler(HWND wnd,UINT msg, WPARAM wParam, LPARAM lParam);
       };
     }
