@@ -55,7 +55,6 @@ namespace Lum {
 
   private:
     void ResizePoints();
-    void DrawPoint(size_t x, bool scroll);
     void CalculateBounds(int &xo, int &yo, size_t &wo, size_t &ho);
     int TransformY(double value, size_t height);
 
@@ -66,12 +65,19 @@ namespace Lum {
     void SetRange(double bottom, double top);
     void SetInterval(size_t horiz, size_t vert);
     void SetColor(size_t channel, OS::Color color);
-    void Clear();
     bool SetModel(Base::Model* model);
 
+    void Clear();
+    double GetBottom() const;
+    double GetTop() const;
+
     void CalcSize();
     void Draw(int x, int y, size_t w, size_t h);
     void Resync(Base::Model* model, const Base::ResyncMsg& msg);
+
+    static TimeLine* Create(bool horizontalFlex=false, bool verticalFlex=false);
+    static TimeLine* Create(Base::Model* model, bool horizontalFlex=false, bool verticalFlex=false);
+    static TimeLine* Create(Base::Model* model, double bottom, double top, bool horizontalFlex=false, bool verticalFlex=false);
   };
 }
 
