@@ -160,19 +160,20 @@ namespace Lum {
 
     group->CalcSize();
 
-    if (OS::display->GetType()==OS::Display::typeTextual && window->GetType()==OS::Window::typeMain) {
+    if (OS::display->GetType()==OS::Display::typeTextual &&
+        window->GetType()==OS::Window::typeMain) {
       group->Resize(OS::display->GetWorkAreaWidth(),OS::display->GetWorkAreaHeight());
     }
 
     window->SetSize(group->GetOWidth(),group->GetOHeight());
 
-    if (window->GetX()+window->GetWidth()-1>OS::display->GetScreenWidth()
-        && window->GetWidth()<OS::display->GetScreenWidth()) {
+    if (window->GetX()+window->GetWidth()-1>OS::display->GetScreenWidth() &&
+        window->GetWidth()<OS::display->GetScreenWidth()) {
       window->SetPos(OS::display->GetScreenWidth()-window->GetWidth(),
                      window->GetY());
     }
-    if (window->GetY()+window->GetHeight()-1>OS::display->GetScreenHeight()
-        && window->GetHeight()<OS::display->GetScreenHeight()) {
+    if (window->GetY()+window->GetHeight()-1>OS::display->GetScreenHeight() &&
+        window->GetHeight()<OS::display->GetScreenHeight()) {
       window->SetPos(window->GetX(),
                      OS::display->GetScreenHeight()-window->GetHeight());
     }
@@ -200,7 +201,8 @@ namespace Lum {
 
   void Dialog::Resync(Base::Model* model, const Base::ResyncMsg& msg)
   {
-    if (model==GetWindow()->GetResizeAction() && GetWindow()->GetResizeAction()->IsFinished()) {
+    if (model==GetWindow()->GetResizeAction() &&
+        GetWindow()->GetResizeAction()->IsFinished()) {
       if (GetWindow()->GetType()==OS::Window::typeMain) {
         if (GetWindow()->IsFullScreen()) {
           GetMain()->SetBackground(OS::display->GetFill(OS::Display::backgroundFillIndex));
@@ -210,7 +212,8 @@ namespace Lum {
         }
       }
     }
-    else if (model==GetWindow()->GetMenuAction() && GetWindow()->GetMenuAction()->IsFinished()) {
+    else if (model==GetWindow()->GetMenuAction() &&
+             GetWindow()->GetMenuAction()->IsFinished()) {
       if (OS::display->GetTheme()->GetMenuType()==OS::Theme::menuTypeCustom &&
           customMenuHandler!=NULL) {
         /* ignore */ customMenuHandler->Open();
