@@ -530,7 +530,7 @@ namespace Lum {
       size_t   i;
       int      xPos;
 
-      cX=Base::RoundRange(cX,this->x,this->x+width-1)-this->x;
+      cX=Base::RoundRange(cX,this->x,this->x+(int)width-1)-this->x;
 
       y=GetFirstVisiblePos()+(cY-this->y)/font->height;
 
@@ -1856,11 +1856,21 @@ namespace Lum {
       OS::display->KeyToKeyDescription(event.qualifier,name,description);
 
 
-      if (window->IsTrippleClicked()) {
+      /*if (window->IsTrippleClicked()) {
         description+=L"-trippleclick";
       }
-      else if (window->IsDoubleClicked()) {
-        description+=L"-doubleclick";
+      else */
+      if (window->IsDoubleClicked()) {
+        size_t px,py,tx,ty;
+
+        if (PointIsIn(GetWindow()->GetLastButtonClickEvent()) &&
+            CoordsToTextPos(window->GetLastButtonClickEvent().x,
+                            window->GetLastButtonClickEvent().y,
+                            px,py) &&
+            CoordsToTextPos(event.x,event.y,tx,ty) &&
+            px==tx && py==ty) {
+          description+=L"-doubleclick";
+        }
       }
 
       if (description==L"MouseButton1") {
