@@ -181,7 +181,7 @@ namespace Lum {
      */
     void Adjustment::SetTop(size_t top)
     {
-      assert(top);
+      assert(top>=1);
       assert(top<=total->Get()-visible->Get()+1);
 
       if (this->top->IsNull() || this->top->Get()!=top) {
