@@ -139,31 +139,31 @@ namespace Lum {
     draw->PushClip(x+boxFrame->leftBorder,
                    y+offset,
                    kStart,
-                   knob->GetHeight());
+                   knobHeight);
 
     OS::ImageRef filled=OS::display->GetImage(OS::Display::leftSliderImageIndex);
     OS::ImageRef unfilled=OS::display->GetImage(OS::Display::rightSliderImageIndex);
 
-    filled->Draw(draw,
-                 x+boxFrame->leftBorder,
-                 y+offset,
-                 width-boxFrame->minWidth,
-                 knob->GetHeight());
+    filled->DrawStretched(draw,
+                          x+boxFrame->leftBorder,
+                          y+offset,
+                          width-boxFrame->minWidth,
+                          knobHeight);
 
     draw->PopClip();
 
-    knob->Draw(draw,knobX,knobY,knobWidth,knobHeight);
+    knob->Draw(draw,knobX,knobY);
 
-    draw->PushClip(x+boxFrame->leftBorder+kStart+knob->GetWidth(),
+    draw->PushClip(x+boxFrame->leftBorder+kStart+knobWidth,
                    y+offset,
-                   width-boxFrame->minWidth-kStart-knob->GetWidth(),
-                   knob->GetHeight());
+                   width-boxFrame->minWidth-kStart-knobWidth,
+                   knobHeight);
 
-    unfilled->Draw(draw,
-                   x+boxFrame->leftBorder,
-                   y+offset,
-                   width-boxFrame->minWidth,
-                   knob->GetHeight());
+    unfilled->DrawStretched(draw,
+                            x+boxFrame->leftBorder,
+                            y+offset,
+                            width-boxFrame->minWidth,
+                            knobHeight);
 
     draw->PopClip();
 
@@ -441,26 +441,26 @@ namespace Lum {
     OS::ImageRef filled=OS::display->GetImage(OS::Display::bottomSliderImageIndex);
     OS::ImageRef unfilled=OS::display->GetImage(OS::Display::topSliderImageIndex);
 
-    unfilled->Draw(draw,
-                   x+offset,
-                   y+boxFrame->topBorder,
-                   knob->GetWidth(),
-                   height-boxFrame->minHeight);
+    unfilled->DrawStretched(draw,
+                            x+offset,
+                            y+boxFrame->topBorder,
+                            knobWidth,
+                            height-boxFrame->minHeight);
 
     draw->PopClip();
 
-    knob->Draw(draw,knobX,knobY,knobWidth,knobHeight);
+    knob->Draw(draw,knobX,knobY);
 
     draw->PushClip(x+offset,
-                   y+boxFrame->topBorder+kStart+knob->GetHeight(),
-                   knob->GetWidth(),
-                   height-boxFrame->minHeight-kStart-knob->GetHeight());
+                   y+boxFrame->topBorder+kStart+knobHeight,
+                   knobWidth,
+                   height-boxFrame->minHeight-kStart-knobHeight);
 
-    filled->Draw(draw,
-                 x+offset,
-                 y+boxFrame->topBorder,
-                 knob->GetWidth(),
-                 height-boxFrame->minHeight);
+    filled->DrawStretched(draw,
+                          x+offset,
+                          y+boxFrame->topBorder,
+                          knobWidth,
+                          height-boxFrame->minHeight);
 
     draw->PopClip();
 
